labeltools
==========

.. automodule:: abjad.tools.labeltools

.. only:: html

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.labeltools.color_chord_note_heads_in_expr_by_pitch_class_color_map.color_chord_note_heads_in_expr_by_pitch_class_color_map
      ~abjad.tools.labeltools.color_contents_of_container.color_contents_of_container
      ~abjad.tools.labeltools.color_leaf.color_leaf
      ~abjad.tools.labeltools.color_leaves_in_expr.color_leaves_in_expr
      ~abjad.tools.labeltools.color_measure.color_measure
      ~abjad.tools.labeltools.color_measures_with_non_power_of_two_denominators_in_expr.color_measures_with_non_power_of_two_denominators_in_expr
      ~abjad.tools.labeltools.color_note_head_by_numbered_pitch_class_color_map.color_note_head_by_numbered_pitch_class_color_map
      ~abjad.tools.labeltools.label_leaves_in_expr_with_leaf_depth.label_leaves_in_expr_with_leaf_depth
      ~abjad.tools.labeltools.label_leaves_in_expr_with_leaf_duration.label_leaves_in_expr_with_leaf_duration
      ~abjad.tools.labeltools.label_leaves_in_expr_with_leaf_durations.label_leaves_in_expr_with_leaf_durations
      ~abjad.tools.labeltools.label_leaves_in_expr_with_leaf_indices.label_leaves_in_expr_with_leaf_indices
      ~abjad.tools.labeltools.label_leaves_in_expr_with_leaf_numbers.label_leaves_in_expr_with_leaf_numbers
      ~abjad.tools.labeltools.label_leaves_in_expr_with_named_interval_classes.label_leaves_in_expr_with_named_interval_classes
      ~abjad.tools.labeltools.label_leaves_in_expr_with_named_intervals.label_leaves_in_expr_with_named_intervals
      ~abjad.tools.labeltools.label_leaves_in_expr_with_numbered_interval_classes.label_leaves_in_expr_with_numbered_interval_classes
      ~abjad.tools.labeltools.label_leaves_in_expr_with_numbered_intervals.label_leaves_in_expr_with_numbered_intervals
      ~abjad.tools.labeltools.label_leaves_in_expr_with_numbered_inversion_equivalent_interval_classes.label_leaves_in_expr_with_numbered_inversion_equivalent_interval_classes
      ~abjad.tools.labeltools.label_leaves_in_expr_with_pitch_class_numbers.label_leaves_in_expr_with_pitch_class_numbers
      ~abjad.tools.labeltools.label_leaves_in_expr_with_pitch_numbers.label_leaves_in_expr_with_pitch_numbers
      ~abjad.tools.labeltools.label_leaves_in_expr_with_tuplet_depth.label_leaves_in_expr_with_tuplet_depth
      ~abjad.tools.labeltools.label_leaves_in_expr_with_written_leaf_duration.label_leaves_in_expr_with_written_leaf_duration
      ~abjad.tools.labeltools.label_logical_ties_in_expr_with_logical_tie_duration.label_logical_ties_in_expr_with_logical_tie_duration
      ~abjad.tools.labeltools.label_logical_ties_in_expr_with_logical_tie_durations.label_logical_ties_in_expr_with_logical_tie_durations
      ~abjad.tools.labeltools.label_logical_ties_in_expr_with_written_logical_tie_duration.label_logical_ties_in_expr_with_written_logical_tie_duration
      ~abjad.tools.labeltools.label_notes_in_expr_with_note_indices.label_notes_in_expr_with_note_indices
      ~abjad.tools.labeltools.label_vertical_moments_in_expr_with_interval_class_vectors.label_vertical_moments_in_expr_with_interval_class_vectors
      ~abjad.tools.labeltools.label_vertical_moments_in_expr_with_named_intervals.label_vertical_moments_in_expr_with_named_intervals
      ~abjad.tools.labeltools.label_vertical_moments_in_expr_with_numbered_interval_classes.label_vertical_moments_in_expr_with_numbered_interval_classes
      ~abjad.tools.labeltools.label_vertical_moments_in_expr_with_numbered_intervals.label_vertical_moments_in_expr_with_numbered_intervals
      ~abjad.tools.labeltools.label_vertical_moments_in_expr_with_numbered_pitch_classes.label_vertical_moments_in_expr_with_numbered_pitch_classes
      ~abjad.tools.labeltools.label_vertical_moments_in_expr_with_pitch_numbers.label_vertical_moments_in_expr_with_pitch_numbers
      ~abjad.tools.labeltools.remove_markup_from_leaves_in_expr.remove_markup_from_leaves_in_expr
